PyDateTime
==========

.. currentmodule:: cysgp4

.. autoclass:: PyDateTime
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~PyDateTime.datetime
      ~PyDateTime.mjd
      ~PyDateTime.ticks
      ~PyDateTime.tle_epoch

   .. rubric:: Methods Summary

   .. autosummary::

      ~PyDateTime.from_mjd
      ~PyDateTime.from_ticks
      ~PyDateTime.from_tle_epoch
      ~PyDateTime.get_datetime_tuple
      ~PyDateTime.gmst
      ~PyDateTime.lmst
      ~PyDateTime.set

   .. rubric:: Attributes Documentation

   .. autoattribute:: datetime
   .. autoattribute:: mjd
   .. autoattribute:: ticks
   .. autoattribute:: tle_epoch

   .. rubric:: Methods Documentation

   .. automethod:: from_mjd
   .. automethod:: from_ticks
   .. automethod:: from_tle_epoch
   .. automethod:: get_datetime_tuple
   .. automethod:: gmst
   .. automethod:: lmst
   .. automethod:: set
